==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ComboBoxColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ComboBoxColumnDescription } from "./ComboBoxColumnDescription";
/**
 * @hidden
 */
export let ComboBoxColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class ComboBoxColumnDescriptionMetadata extends Base {
        static b(a) {
            if (ComboBoxColumnDescriptionMetadata.a == null) {
                ComboBoxColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ComboBoxColumnDescriptionMetadata.c(ComboBoxColumnDescriptionMetadata.a);
            }
            if (a.k(ComboBoxColumnDescriptionMetadata.a)) {
                return;
            }
            a.ab(ComboBoxColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
            a.item("DataSource", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("TextField", "String");
            a.item("ValueField", "String");
        }
        static d(a) {
            ComboBoxColumnDescriptionMetadata.b(a);
            a.ad("ComboBoxColumn", () => new ComboBoxColumnDescription());
            a.ac("ComboBoxColumn", ComboBoxColumnDescriptionMetadata.a);
        }
    }
    ComboBoxColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(ComboBoxColumnDescriptionMetadata, 'ComboBoxColumnDescriptionMetadata');
    ComboBoxColumnDescriptionMetadata.a = null;
    return ComboBoxColumnDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/ComboBoxColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ComboBoxColumnDescription } from "./ComboBoxColumnDescription";
/**
 * @hidden
 */
export let ComboBoxColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class ComboBoxColumnDescriptionMetadata extends Base {
        static b(a) {
            if (ComboBoxColumnDescriptionMetadata.a == null) {
                ComboBoxColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ComboBoxColumnDescriptionMetadata.c(ComboBoxColumnDescriptionMetadata.a);
            }
            if (a.k(ComboBoxColumnDescriptionMetadata.a)) {
                return;
            }
            a.ac(ComboBoxColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataGridColumnDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)DataRef::object");
            a.item("DataSource", "(w:ItemsSource,xam:ItemsSource,wf:ItemsSource)ExportedType:BaseDataSource:BaseDataSource");
            a.item("TextField", "String");
            a.item("ValueField", "String");
        }
        static d(a) {
            ComboBoxColumnDescriptionMetadata.b(a);
            a.ae("ComboBoxColumn", () => new ComboBoxColumnDescription());
            a.ad("ComboBoxColumn", ComboBoxColumnDescriptionMetadata.a);
        }
    }
    ComboBoxColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(ComboBoxColumnDescriptionMetadata, 'ComboBoxColumnDescriptionMetadata');
    ComboBoxColumnDescriptionMetadata.a = null;
    return ComboBoxColumnDescriptionMetadata;
})();
